import{N as f}from"./NavbarControls.76589c96.js";import{d as l,ey as _,ez as y,F as g,a as v,b as m,et as h,f as e,w as a,u as s,e as k,bo as w,ao as S,c as x,eS as T,t as q}from"./outputWidgets.8246053b.js";import{A as C}from"./Text.2015d383.js";import{T as I,A as o}from"./TabPane.dba132c6.js";import{c as A}from"./index.a5b51084.js";import"./asyncComputed.e925ebe9.js";import"./index.b7597569.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.ae17871c.js";import"./SaveButton.vue_vue_type_script_setup_true_lang.6d4e7d7a.js";import"./ant-design.bd80aae5.js";import"./index.b9f3321e.js";import"./Modal.ab74e114.js";import"./storage.195d9a4f.js";import"./Link.02660225.js";import"./index.ebe170ee.js";import"./Title.f9200d53.js";import"./index.1705b04e.js";import"./workspaces.0c83963a.js";import"./record.112817cd.js";import"./pubsub.cf08d0ee.js";import"./url.9664ee35.js";import"./popupNotifcation.0ebf57e5.js";import"./CircularLoading.1e5872a3.js";import"./icons.1afdbafb.js";import"./index.4ad5f5f8.js";import"./hasIn.afa75b8c.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[t]="fa2a5dd2-bba3-4e30-905b-75b419fa5f19",r._sentryDebugIdIdentifier="sentry-dbid-fa2a5dd2-bba3-4e30-905b-75b419fa5f19")}catch{}})();const B={class:"content"},D=l({__name:"Settings",setup(r){const t=_(),n=y();function p(){t.push({name:"home"})}const c=g(()=>{switch(n.name){case"settingsStyle":return"style";case"settingsSidebar":return"sidebar";case"settingsRequirements":return"requirements";default:return}});function u(i){switch(i){case"style":t.push({name:"settingsStyle"});break;case"sidebar":t.push({name:"settingsSidebar"});break;case"requirements":t.push({name:"settingsRequirements"});break}}return(i,N)=>{const d=v("router-view");return m(),h(w,null,[e(s(A),{style:{padding:"5px 25px"},onBack:p},{extra:a(()=>[e(f,{"show-v-s-code-button":"","show-save-button":""})]),avatar:a(()=>[e(s(C),null,{default:a(()=>[S("Settings")]),_:1})]),footer:a(()=>[e(s(I),{"active-key":c.value,onChange:u},{default:a(()=>[e(s(o),{key:"style",tab:"Style"}),e(s(o),{key:"sidebar",tab:"Sidebar"}),e(s(o),{key:"requirements",tab:"Requirements"})]),_:1},8,["active-key"])]),_:1}),k("div",B,[e(d,null,{default:a(({Component:b})=>[(m(),x(T(b)))]),_:1})])],64)}}});const oe=q(D,[["__scopeId","data-v-772f4b10"]]);export{oe as default};
//# sourceMappingURL=Settings.2e05d6a6.js.map
