import{C as r,E as t,K as b,a as i,M as f,c,P as l,R as y,S as g,b as u,T as k,U as p,e as w,l as D}from"./toggleHighContrast.64dabd57.js";import"./outputWidgets.8246053b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="2df75d9d-91be-41b1-b5bb-d3265caabfb3",e._sentryDebugIdIdentifier="sentry-dbid-2df75d9d-91be-41b1-b5bb-d3265caabfb3")}catch{}})();export{r as CancellationTokenSource,t as Emitter,b as KeyCode,i as KeyMod,f as MarkerSeverity,c as MarkerTag,l as Position,y as Range,g as Selection,u as SelectionDirection,k as Token,p as Uri,w as editor,D as languages};
//# sourceMappingURL=editor.main.3c4be83f.js.map
