import{t as n,b as s,et as o}from"./outputWidgets.8246053b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="e4fd3379-9985-4989-816f-44ccb4b3a12f",e._sentryDebugIdIdentifier="sentry-dbid-e4fd3379-9985-4989-816f-44ccb4b3a12f")}catch{}})();const r={},i={class:"organization-settings"};function a(e,t){return s(),o("div",i,"Organization settings")}const f=n(r,[["render",a]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.9b2581ca.js.map
