import{a as e,A as t,B as i}from"./Text.2015d383.js";import{A as o}from"./Link.02660225.js";import{a as r,A as f}from"./Title.f9200d53.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[n]="4efc96a0-2fff-4b3a-a587-334296afb563",a._sentryDebugIdIdentifier="sentry-dbid-4efc96a0-2fff-4b3a-a587-334296afb563")}catch{}})();e.Text=t;e.Title=r;e.Paragraph=f;e.Link=o;e.Base=i;e.install=function(a){return a.component(e.name,e),a.component(e.Text.displayName,t),a.component(e.Title.displayName,r),a.component(e.Paragraph.displayName,f),a.component(e.Link.displayName,o),a};
//# sourceMappingURL=index.ebe170ee.js.map
