import"./outputWidgets.8246053b.js";(function(){try{var c=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(c._sentryDebugIds=c._sentryDebugIds||{},c._sentryDebugIds[e]="b26b4c3c-5911-4c25-9da5-78c1cc151448",c._sentryDebugIdIdentifier="sentry-dbid-b26b4c3c-5911-4c25-9da5-78c1cc151448")}catch{}})();class r{static get(e){try{const t=localStorage.getItem(e);return t&&JSON.parse(t)}catch{return null}}static set(e,t){localStorage.setItem(e,JSON.stringify(t))}static pop(e){const t=r.get(e);return r.remove(e),t}static remove(e){localStorage.removeItem(e)}}export{r as S};
//# sourceMappingURL=storage.195d9a4f.js.map
