import{cu as d}from"./outputWidgets.8246053b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="662fb9d1-6219-4599-9343-1f73d177cbc3",e._sentryDebugIdIdentifier="sentry-dbid-662fb9d1-6219-4599-9343-1f73d177cbc3")}catch{}})();const t=(e,r)=>{d.error({message:e,description:r})};export{t as p};
//# sourceMappingURL=popupNotifcation.0ebf57e5.js.map
