import{t as r,a,b as i,c as d,i as c,T as p,j as _,P as u,C as b,M as f,s as l,k as s,l as g,m,n as y,p as v}from"./outputWidgets.8246053b.js";import{s as w,a as o}from"./index.b7597569.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="2d0a4617-b632-4d91-a0b7-e11b456865d4",e._sentryDebugIdIdentifier="sentry-dbid-2d0a4617-b632-4d91-a0b7-e11b456865d4")}catch{}})();const h={};function I(e,t){const n=a("router-view");return i(),d(n,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const k=r(h,[["render",I]]);class x{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await w();const e=c({render:()=>g(k)});p.init(),_(e,o),x.init(),e.use(o),e.use(u),e.mount("#app"),e.component("VSelect",b),e.component("Markdown",f),e.component("Message",l),s(e,m),s(e,y),s(e,v)})();
//# sourceMappingURL=player.98a2f211.js.map
