import{S as c}from"./Sidebar.ca98d454.js";import{_ as p}from"./Navbar.vue_vue_type_script_setup_true_lang.2ea178c5.js";import{G as d,H as l,I as u}from"./icons.1afdbafb.js";import{d as b,ez as f,F as g,a as _,b as y,c as v,w as a,f as r}from"./outputWidgets.8246053b.js";import{a as z}from"./asyncComputed.e925ebe9.js";import"./router.ee3d3d59.js";import"./jwt-decode.esm.74bd4619.js";import"./index.ab651559.js";import{O as w}from"./organization.4091f5b4.js";import{B as I}from"./BaseLayout.1666614a.js";import"./index.47f3a57d.js";import"./logo.084e5d7c.js";import"./Text.2015d383.js";import"./index.a5b51084.js";import"./FormItem.377ec60f.js";import"./hasIn.afa75b8c.js";import"./storage.195d9a4f.js";import"./index.2b26c55a.js";import"./index.cf4c23b9.js";import"./record.112817cd.js";import"./pubsub.cf08d0ee.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="cb67c2cc-7496-42f9-84c9-945669a91b02",o._sentryDebugIdIdentifier="sentry-dbid-cb67c2cc-7496-42f9-84c9-945669a91b02")}catch{}})();const K=b({__name:"Organization",setup(o){const n=f().params.organizationId,{result:t}=z(()=>w.get(n)),i=g(()=>t.value?[{label:"My organizations",path:"/organizations"},{label:t.value.name,path:`/organizations/${t.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:d,path:"projects"},{name:"Members",icon:l,path:"members"},{name:"Billing",icon:u,path:"billing"}]}];return(h,B)=>{const m=_("router-view");return y(),v(I,null,{navbar:a(()=>[r(p,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:a(()=>[r(c,{class:"sidebar",sections:s})]),content:a(()=>[r(m)]),_:1})}}});export{K as default};
//# sourceMappingURL=Organization.4d80868f.js.map
