import{Q as s}from"./outputWidgets.8246053b.js";import{c as i,d}from"./index.dad2dec4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="7621bb64-1620-4fc8-b935-cdc43aead208",e._sentryDebugIdIdentifier="sentry-dbid-7621bb64-1620-4fc8-b935-cdc43aead208")}catch{}})();const{DatePicker:n,WeekPicker:r,MonthPicker:t,YearPicker:f,TimePicker:m,QuarterPicker:o,RangePicker:c}=i(d),y=s(n,{WeekPicker:r,MonthPicker:t,YearPicker:f,RangePicker:c,TimePicker:m,QuarterPicker:o,install:e=>(e.component(n.name,n),e.component(c.name,c),e.component(t.name,t),e.component(r.name,r),e.component(o.name,o),e)});export{y as D,t as M,o as Q,c as R,r as W};
//# sourceMappingURL=dayjs.ce1421d2.js.map
