import"./outputWidgets.8246053b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="9881e34f-af71-425c-b940-15e96ae8547a",e._sentryDebugIdIdentifier="sentry-dbid-9881e34f-af71-425c-b940-15e96ae8547a")}catch{}})();const d=e=>{try{return new URL(e),!0}catch{return!1}};export{d as i};
//# sourceMappingURL=url.9664ee35.js.map
