var o=Object.defineProperty;var i=(t,e,r)=>e in t?o(t,e,{enumerable:!0,configurable:!0,writable:!0,value:r}):t[e]=r;var n=(t,e,r)=>(i(t,typeof e!="symbol"?e+"":e,r),r);import{g as c,h as f,_ as d}from"./outputWidgets.8246053b.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="f88760ed-8417-4238-bc2e-ef3399fe4a6c",t._sentryDebugIdIdentifier="sentry-dbid-f88760ed-8417-4238-bc2e-ef3399fe4a6c")}catch{}})();const u=[{path:"/:path(.*)*",name:"player",component:()=>d(()=>import("./Player.c2e2acf8.js"),["assets/Player.c2e2acf8.js","assets/FormRunner.f3685d2b.js","assets/outputWidgets.8246053b.js","assets/outputWidgets.bd537527.css","assets/url.9664ee35.js","assets/storage.195d9a4f.js","assets/pubsub.cf08d0ee.js","assets/jwt-decode.esm.74bd4619.js","assets/icons.1afdbafb.js","assets/CircularLoading.1e5872a3.js","assets/CircularLoading.f81b57b4.css","assets/PlayerNavbar.db378e88.js","assets/PlayerNavbar.ead94b03.css","assets/ActionButton.5ed85e5b.js","assets/ActionButton.f74e60ec.css","assets/WidgetsFrame.261785c8.js","assets/WidgetsFrame.97ae601d.css","assets/index.641ea4b3.js","assets/Card.bfcd52ec.js","assets/TabPane.dba132c6.js","assets/hasIn.afa75b8c.js","assets/index.ebe170ee.js","assets/Text.2015d383.js","assets/Link.02660225.js","assets/Title.f9200d53.js","assets/FormRunner.8ff3f1ac.css","assets/uuid.217d3f2d.js","assets/asyncComputed.e925ebe9.js","assets/Player.6fed9080.css"])}],g=c({history:f("/"),routes:u,scrollBehavior(t){if(t.hash)return{el:t.hash}}});async function w(){const t=await fetch("/_settings");if(!t.ok)throw new Error(await t.text());const e=await t.json();await s.init(e)}const a=class{constructor(e){this.config=e}static async init(e){a.instance=new a(e)}get showWatermark(){return this.config.show_watermark}get isStagingRelease(){return{}.VITE_ABSTRA_RELEASE==="staging"}get isLocal(){return location.origin.match(/http:\/\/localhost:\d+/)}};let s=a;n(s,"instance",null);export{s as S,g as a,u as r,w as s};
//# sourceMappingURL=index.b7597569.js.map
